==> zio-aws-firehose_2.13-7.28.26.1-sources.jar: zio/aws/firehose/model/SourceDescription.scala <==
package zio.aws.firehose.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SourceDescription(
    kinesisStreamSourceDescription: Optional[
      zio.aws.firehose.model.KinesisStreamSourceDescription
    ] = Optional.Absent,
    mskSourceDescription: Optional[
      zio.aws.firehose.model.MSKSourceDescription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.SourceDescription = {
    import SourceDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.SourceDescription
      .builder()
      .optionallyWith(
        kinesisStreamSourceDescription.map(value => value.buildAwsValue())
      )(_.kinesisStreamSourceDescription)
      .optionallyWith(mskSourceDescription.map(value => value.buildAwsValue()))(
        _.mskSourceDescription
      )
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.SourceDescription.ReadOnly =
    zio.aws.firehose.model.SourceDescription.wrap(buildAwsValue())
}
object SourceDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.SourceDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.SourceDescription =
      zio.aws.firehose.model.SourceDescription(
        kinesisStreamSourceDescription.map(value => value.asEditable),
        mskSourceDescription.map(value => value.asEditable)
      )
    def kinesisStreamSourceDescription: Optional[
      zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly
    ]
    def mskSourceDescription
        : Optional[zio.aws.firehose.model.MSKSourceDescription.ReadOnly]
    def getKinesisStreamSourceDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisStreamSourceDescription",
      kinesisStreamSourceDescription
    )
    def getMskSourceDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.MSKSourceDescription.ReadOnly
    ] = AwsError.unwrapOptionField("mskSourceDescription", mskSourceDescription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.SourceDescription
  ) extends zio.aws.firehose.model.SourceDescription.ReadOnly {
    override val kinesisStreamSourceDescription: Optional[
      zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.kinesisStreamSourceDescription())
      .map(value =>
        zio.aws.firehose.model.KinesisStreamSourceDescription.wrap(value)
      )
    override val mskSourceDescription
        : Optional[zio.aws.firehose.model.MSKSourceDescription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.mskSourceDescription())
        .map(value => zio.aws.firehose.model.MSKSourceDescription.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.SourceDescription
  ): zio.aws.firehose.model.SourceDescription.ReadOnly = new Wrapper(impl)
}

==> zio-aws-firehose_3-5.17.104.5-sources.jar: zio/aws/firehose/model/SourceDescription.scala <==
package zio.aws.firehose.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SourceDescription(
    kinesisStreamSourceDescription: Option[
      zio.aws.firehose.model.KinesisStreamSourceDescription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.SourceDescription = {
    import SourceDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.SourceDescription
      .builder()
      .optionallyWith(
        kinesisStreamSourceDescription.map(value => value.buildAwsValue())
      )(_.kinesisStreamSourceDescription)
      .build()
  }
  def asReadOnly: zio.aws.firehose.model.SourceDescription.ReadOnly =
    zio.aws.firehose.model.SourceDescription.wrap(buildAwsValue())
}
object SourceDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.SourceDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.SourceDescription =
      zio.aws.firehose.model.SourceDescription(
        kinesisStreamSourceDescription.map(value => value.asEditable)
      )
    def kinesisStreamSourceDescription
        : Option[zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly]
    def getKinesisStreamSourceDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "kinesisStreamSourceDescription",
      kinesisStreamSourceDescription
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.SourceDescription
  ) extends zio.aws.firehose.model.SourceDescription.ReadOnly {
    override val kinesisStreamSourceDescription: Option[
      zio.aws.firehose.model.KinesisStreamSourceDescription.ReadOnly
    ] = scala
      .Option(impl.kinesisStreamSourceDescription())
      .map(value =>
        zio.aws.firehose.model.KinesisStreamSourceDescription.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.SourceDescription
  ): zio.aws.firehose.model.SourceDescription.ReadOnly = new Wrapper(impl)
}
